Documentation
¶
Index ¶
- func Banner(s *State)
- func GoGet(s *State, url, uri, cookie string) (*int, *int64)
- func MakeRequest(s *State, fullUrl, cookie string) (*int, *int64)
- func PrepareSignalHandler(s *State)
- func PrintDirResult(s *State, r *Result)
- func PrintDnsResult(s *State, r *Result)
- func Process(s *State)
- func ProcessDirEntry(s *State, word string, resultChan chan<- Result)
- func ProcessDnsEntry(s *State, word string, resultChan chan<- Result)
- func Ruler(s *State)
- func SetupDir(s *State) bool
- func SetupDns(s *State) bool
- func ShowConfig(s *State)
- func ValidateDirModeState(s *State, extensions string, codes string, proxy string, ...) *multierror.Error
- func ValidateState(s *State, extensions string, codes string, proxy string) *multierror.Error
- func WriteToFile(output string, s *State)
- type IntSet
- type PrintResultFunc
- type ProcessorFunc
- type RedirectError
- type RedirectHandler
- type Result
- type SetupFunc
- type State
- type StringSet
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MakeRequest ¶
Make a request to the given URL.
func PrepareSignalHandler ¶
func PrepareSignalHandler(s *State)
func PrintDirResult ¶
func PrintDnsResult ¶
func Process ¶
func Process(s *State)
Process the busting of the website with the given set of settings from the command line.
func ProcessDirEntry ¶
func ProcessDnsEntry ¶
func ShowConfig ¶
func ShowConfig(s *State)
func ValidateDirModeState ¶
func ValidateDirModeState( s *State, extensions string, codes string, proxy string, previousErrors *multierror.Error) *multierror.Error
func ValidateState ¶
func WriteToFile ¶
Types ¶
type PrintResultFunc ¶
type ProcessorFunc ¶
type RedirectError ¶
type RedirectError struct {
StatusCode int
}
func (*RedirectError) Error ¶
func (e *RedirectError) Error() string
type RedirectHandler ¶
type RedirectHandler struct {
Transport http.RoundTripper
State *State
}
type State ¶
type State struct {
Client *http.Client
Cookies string
Expanded bool
Extensions []string
FollowRedirect bool
IncludeLength bool
Mode string
NoStatus bool
Password string
Printer PrintResultFunc
Processor ProcessorFunc
ProxyUrl *url.URL
Quiet bool
Setup SetupFunc
ShowIPs bool
ShowCNAME bool
StatusCodes IntSet
Threads int
Url string
UseSlash bool
UserAgent string
Username string
Verbose bool
Wordlist string
OutputFileName string
OutputFile *os.File
IsWildcard bool
WildcardForced bool
WildcardIps StringSet
SignalChan chan os.Signal
Terminate bool
StdIn bool
InsecureSSL bool
}
Contains State that are read in from the command line when the program is invoked.
Click to show internal directories.
Click to hide internal directories.