Documentation
¶
Index ¶
- type GobusterTFTP
- func (d *GobusterTFTP) AdditionalSuccessWords(_ string) []string
- func (d *GobusterTFTP) AdditionalWords(_ string) []string
- func (d *GobusterTFTP) AdditionalWordsLen() int
- func (d *GobusterTFTP) GetConfigString() (string, error)
- func (d *GobusterTFTP) Name() string
- func (d *GobusterTFTP) PreRun(_ context.Context, _ *libgobuster.Progress) error
- func (d *GobusterTFTP) ProcessWord(_ context.Context, word string, progress *libgobuster.Progress) (libgobuster.Result, error)
- type OptionsTFTP
- type Result
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GobusterTFTP ¶
type GobusterTFTP struct {
// contains filtered or unexported fields
}
GobusterTFTP is the main type to implement the interface
func New ¶ added in v3.7.0
func New(globalopts *libgobuster.Options, opts *OptionsTFTP) (*GobusterTFTP, error)
New creates a new initialized NewGobusterTFTP
func (*GobusterTFTP) AdditionalSuccessWords ¶ added in v3.7.0
func (d *GobusterTFTP) AdditionalSuccessWords(_ string) []string
func (*GobusterTFTP) AdditionalWords ¶
func (d *GobusterTFTP) AdditionalWords(_ string) []string
func (*GobusterTFTP) AdditionalWordsLen ¶ added in v3.7.0
func (d *GobusterTFTP) AdditionalWordsLen() int
func (*GobusterTFTP) GetConfigString ¶
func (d *GobusterTFTP) GetConfigString() (string, error)
GetConfigString returns the string representation of the current config
func (*GobusterTFTP) Name ¶
func (d *GobusterTFTP) Name() string
Name should return the name of the plugin
func (*GobusterTFTP) PreRun ¶
func (d *GobusterTFTP) PreRun(_ context.Context, _ *libgobuster.Progress) error
PreRun is the pre run implementation of gobustertftp
func (*GobusterTFTP) ProcessWord ¶
func (d *GobusterTFTP) ProcessWord(_ context.Context, word string, progress *libgobuster.Progress) (libgobuster.Result, error)
ProcessWord is the process implementation of gobustertftp
type OptionsTFTP ¶
OptionsTFTP holds all options for the tftp plugin
func NewOptions ¶ added in v3.7.0
func NewOptions() *OptionsTFTP
NewOptions returns a new initialized OptionsTFTP
Click to show internal directories.
Click to hide internal directories.